@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.123 2004/06/01 22:38:07 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.126 2004/06/14 17:57:31 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -130,7 +130,7 @@ static gboolean dismiss_aframe(GtkWidget *, GdkEvent *, gpointer);
 static gboolean dismiss_rframe(GtkWidget *, GdkEvent *, gpointer);
 static gboolean kframe_key_press_cb(GtkWidget *, GdkEventKey *, gpointer);
 
-static void about_cb(GtkWidget *, gpointer);
+static void about_cb(GtkAction *action);
 static void add_cf_column(GtkTreeView *, gchar *, gint, gboolean);
 static void aframe_cancel_cb(GtkButton *, gpointer);
 static void aframe_ok_cb(GtkButton *, gpointer);
@@ -162,7 +162,14 @@ static void set_show_tsep_toggle(int);
 static void set_show_zeroes_toggle(int);
 static void trig_cb(GtkToggleButton *, gpointer);
 static void ts_proc(GtkAction *action);
+static void gcalc_window_have_icons_notify(GConfClient *client, guint cnxn_id,
+                                           GConfEntry *entry, gpointer data);
+static void gcalc_window_get_menu_items(XVars X);
+static void gcalc_window_set_unset_image(gboolean have_icons);
 
+#define MENU_KEY_DIR "/desktop/gnome/interface"
+
+static GSList *list;
 static XVars X;
 
 /* Menubar menus. */
@@ -186,7 +193,7 @@ static GtkActionEntry entries[] = {
     { "Contents", GTK_STOCK_HELP, N_("_Contents"), "F1",
       N_("Show help contents"), G_CALLBACK(mb_proc) },
     { "About", GNOME_STOCK_ABOUT, N_("_About"), NULL,
-      N_("Show about help"), G_CALLBACK(mb_proc) },
+      N_("Show about help"), G_CALLBACK(about_cb) },
 
     { "LSPlaces1",  NULL, N_("1 place"),   NULL, 
       N_("1 place"),   G_CALLBACK(mb_proc) },
@@ -424,7 +431,7 @@ main(int argc, char **argv)
 
 
 static void
-about_cb(GtkWidget *widget, gpointer data)
+about_cb(GtkAction *action)
 {
     static GtkWidget *about = NULL;
 
@@ -925,6 +932,84 @@ create_cfframe(enum menu_type mtype, GtkWidget *dialog)
 }
 
 
+static void
+gcalc_window_get_menu_items(XVars X)
+{
+    GtkAction *act;
+    GSList *p = NULL;
+    gint i = 0;
+
+/* action_image[] is a list of Actions which are having icons associated.
+ * We need to set/unset the icons if 
+ * /desktop/gnome/interface/menus_have_icons toggles.
+ */
+
+    static gchar *action_image[] = {
+        "Quit", 
+        "Copy", 
+        "Paste", 
+        "Contents", 
+        "About", 
+        NULL
+    };
+
+    while (action_image[i]) {
+        act = gtk_action_group_get_action(X->actions, action_image[i]);
+        p = gtk_action_get_proxies(GTK_ACTION(act));
+
+        for (; p; p = p->next) {
+            if (p->data) {
+                if (GTK_IS_MENU_ITEM(p->data)) {
+                    list = g_slist_append(list, p->data);
+                }
+            }
+        }
+
+        i ++;
+    }
+}
+
+
+static void
+gcalc_window_have_icons_notify(GConfClient *client, guint cnxn_id,
+                               GConfEntry *entry, gpointer data)
+{
+    gcalc_window_set_unset_image(gconf_client_get_bool(client, 
+                                 MENU_KEY_DIR"/menus_have_icons", NULL));
+}
+
+
+static void
+gcalc_window_set_unset_image(gboolean have_icons)
+{
+    GtkWidget *image;
+    GSList *temp = list;
+
+    while (temp) {
+        image = gtk_image_menu_item_get_image(GTK_IMAGE_MENU_ITEM(temp->data));
+
+        if (image && ! g_object_get_data(G_OBJECT(temp->data), "saved_image")) {
+            g_object_set_data_full(G_OBJECT(temp->data), "saved_image", 
+                                   g_object_ref (image), g_object_unref);
+        }
+
+        if (!image) {
+            image = g_object_get_data(G_OBJECT(temp->data), "saved_image");
+        }
+
+        if (!have_icons) {
+            gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(temp->data), 
+                                          NULL);
+        } else {
+            gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(temp->data), 
+                                          image);
+        }
+
+        temp = temp->next;
+    }
+}
+
+
 void
 create_kframe()
 {
@@ -1004,7 +1089,8 @@ create_kframe()
     gtk_text_view_set_pixels_below_lines(GTK_TEXT_VIEW(X->display_item), 12);
     gtk_text_view_set_right_margin(GTK_TEXT_VIEW(X->display_item), 6);
 
-    atk_object_set_role (gtk_widget_get_accessible (X->display_item), ATK_ROLE_EDITBAR);
+    atk_object_set_role(gtk_widget_get_accessible(X->display_item), 
+                        ATK_ROLE_EDITBAR);
     set_display("0.00", FALSE);
     gtk_widget_ref(X->display_item);
     gtk_container_set_border_width(GTK_CONTAINER(X->display_item), 2);
@@ -1054,6 +1140,20 @@ create_kframe()
             break;
     }
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(view_widget), TRUE);
+
+    gcalc_window_get_menu_items (X);
+
+    gconf_client_add_dir (X->client,
+                          MENU_KEY_DIR,
+                          GCONF_CLIENT_PRELOAD_NONE,
+                          NULL);
+    gconf_client_notify_add (X->client,
+                             MENU_KEY_DIR"/menus_have_icons",
+                             (GConfClientNotifyFunc)
+                               gcalc_window_have_icons_notify,
+                             NULL, NULL, NULL);
+    gcalc_window_set_unset_image(gconf_client_get_bool(X->client, 
+                                 MENU_KEY_DIR"/menus_have_icons", NULL));
 }
 
 
@@ -2105,7 +2205,8 @@ set_display(char *str, int minimize_changes)
 
 
 #define SET_MENUBAR_ITEM_STATE(i, state) \
-          gtk_widget_set_sensitive(gtk_ui_manager_get_widget(X->ui, i), state)
+          g_object_set(gtk_ui_manager_get_action(X->ui, i),  \
+			"sensitive", state, NULL);
 
 
 /* When an error condition occurs:
@@ -2152,7 +2253,8 @@ set_error_state(int error)
     SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Basic",      !v->error); 
     SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Financial",  !v->error); 
     SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Scientific", !v->error); 
-    SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Trailing",   !v->error); 
+    SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Trailing",
+                           !v->error && (v->modetype == SCIENTIFIC)); 
     SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Thousands",  !v->error); 
     SET_MENUBAR_ITEM_STATE("/MenuBar/ViewMenu/Memory",     !v->error); 
     SET_MENUBAR_ITEM_STATE("/MenuBar/HelpMenu/About",      !v->error);
@@ -2311,7 +2413,9 @@ set_show_zeroes_toggle(int state)
 
     mi = gtk_ui_manager_get_widget(X->ui, "/MenuBar/ViewMenu/Trailing");
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi), state);
-    gtk_widget_set_sensitive(mi, v->modetype == SCIENTIFIC);
+    g_object_set(gtk_ui_manager_get_action(X->ui, 
+                                           "/MenuBar/ViewMenu/Trailing"), 
+                 "sensitive", v->modetype == SCIENTIFIC, NULL);
     v->doing_mi = 0;
 }
 
